@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <QApplication>
@@ -31,30 +19,21 @@
 
 #include "step_version.h"
 
-static const char description[] =
-    I18N_NOOP("Interactive physical simulator");
-
 int main(int argc, char* argv[])
 {
-    KLocalizedString::setApplicationDomain("step");
-
     QApplication app(argc, argv);
-    QApplication::setApplicationName(QStringLiteral("step"));
-    QApplication::setApplicationVersion(STEP_VERSION_STRING);
-    QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-    QApplication::setApplicationDisplayName(i18n("Step"));
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("step")));
+    KLocalizedString::setApplicationDomain("step");
 
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-    KCrash::initialize();
 
     KAboutData aboutData(QStringLiteral("step"),
                          i18n("Step"),
                          STEP_VERSION_STRING,
-                         i18n(description),
+                         i18n("Interactive physical simulator"),
                          KAboutLicense::GPL,
                          i18n("(C) 2007 Vladimir Kuznetsov"),
+                         QString(),
                          i18n("https://edu.kde.org/step")
     );
 
@@ -71,6 +50,9 @@ int main(int argc, char* argv[])
     );
 
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("step")));
+
+    KCrash::initialize();
 
     QCommandLineParser parser;
 
