@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_WORLDMODEL_H
@@ -62,7 +50,7 @@ public:
     Q_DECLARE_FLAGS(UndoFlags, UndoFlag)
 
 public:
-    explicit WorldModel(QObject* parent = 0);
+    explicit WorldModel(QObject* parent = nullptr);
     ~WorldModel();
 
     /** Get QItemSelectionModel associated with this WorldModel */
@@ -76,7 +64,7 @@ public:
     QModelIndex collisionSolverIndex() const; ///< Get index of StepCore::CollisionSolver
     QModelIndex constraintSolverIndex() const; ///< Get index of StepCore::ConstraintSolver
     QModelIndex objectIndex(StepCore::Object* obj) const; ///< Get index of given object by pointer
-    QModelIndex childItemIndex(int n, StepCore::ItemGroup* group = NULL) const; ///< Get index of n-th child of the group
+    QModelIndex childItemIndex(int n, StepCore::ItemGroup* group = nullptr) const; ///< Get index of n-th child of the group
     
     /** Get StepCore::Object by index. \note Never change returned object directly ! */
     StepCore::Object* object(const QModelIndex& index) const;
@@ -114,11 +102,11 @@ public:
     // Add/remove/set functions
     /** Generates new unique item name */
     QString newItemName(const QString& className);
-    StepCore::Item* createItem(const QString& className, StepCore::ItemGroup* parent = 0);
+    StepCore::Item* createItem(const QString& className, StepCore::ItemGroup* parent = nullptr);
     /** Creates new item of className with unique name */
-    StepCore::Item* newItem(const QString& className, StepCore::ItemGroup* parent = 0);
+    StepCore::Item* newItem(const QString& className, StepCore::ItemGroup* parent = nullptr);
     /** Add already created item to the world */
-    void addItem(StepCore::Item* item, StepCore::ItemGroup* parent = 0);
+    void addItem(StepCore::Item* item, StepCore::ItemGroup* parent = nullptr);
     /** Delete item from the world */
     void deleteItem(StepCore::Item* item);
 
@@ -240,7 +228,7 @@ signals:
 protected:
     void resetWorld();
     void emitChanged(bool fullUpdate, bool recalcFn);
-    void addCreatedItem(StepCore::Item* item, StepCore::ItemGroup* parent = 0);
+    void addCreatedItem(StepCore::Item* item, StepCore::ItemGroup* parent = nullptr);
     void removeCreatedItem(StepCore::Item* item);
     StepCore::Solver* swapSolver(StepCore::Solver* solver);
     QList<StepCore::Item*> selectedItems();
