@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "object.h"
@@ -62,7 +50,7 @@ void MetaObject::init() const
 
     // strings
     _classNameTr = QCoreApplication::translate("ObjectClass", _className.toUtf8().constData());
-    _descriptionTr = QCoreApplication::translate(NULL, _description.toUtf8().constData());
+    _descriptionTr = QCoreApplication::translate("ObjectDescription", _description.toUtf8().constData());
 
     _initialized = true;
 }
@@ -114,7 +102,7 @@ void MetaProperty::init() const
 {
     _nameTr = QCoreApplication::translate("PropertyName", _name.toUtf8().constData());
     _unitsTr = QCoreApplication::translate("Units", _units.toUtf8().constData());
-    _descriptionTr = QCoreApplication::translate(NULL, _description.toUtf8().constData());
+    _descriptionTr = QCoreApplication::translate("PropertyDescription", _description.toUtf8().constData());
 
     _initialized = true;
 }
@@ -137,7 +125,7 @@ const MetaProperty* MetaObject::property(const QString& name) const
         const MetaProperty* pr = superClass(i)->property(name);
         if(pr) return pr;
     }*/
-    return NULL;
+    return nullptr;
 }
 
 } // namespace StepCore
