@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** \file solver.h
@@ -78,8 +66,8 @@ public:
                              double* f, double* fvar, void* params);
 
     /** Constructs a solver */
-    explicit Solver(int dimension = 0, Function function = NULL,
-                void* params = NULL, double stepSize = 0.001);
+    explicit Solver(int dimension = 0, Function function = nullptr,
+                void* params = nullptr, double stepSize = 0.001);
     /** Constructs a solver */
     explicit Solver(double stepSize);
 
@@ -124,8 +112,8 @@ public:
     double localErrorRatio() const { return _localErrorRatio; }
 
     /** Calculate function value */
-    virtual int doCalcFn(double* t, const VectorXd* y, const VectorXd* yvar = 0,
-                            VectorXd* f = 0, VectorXd* fvar = 0) = 0;
+    virtual int doCalcFn(double* t, const VectorXd* y, const VectorXd* yvar = nullptr,
+                            VectorXd* f = nullptr, VectorXd* fvar = nullptr) = 0;
 
     /** Integrate.
      *  \param t Current time (will be updated by the new value)
@@ -168,7 +156,7 @@ inline Solver::Solver(int dimension, Function function, void* params, double ste
 }
 
 inline Solver::Solver(double stepSize)
-     : _dimension(0), _function(0), _params(0), _stepSize(stepSize),
+     : _dimension(0), _function(nullptr), _params(nullptr), _stepSize(stepSize),
        _toleranceAbs(0.001), _toleranceRel(0.001), _localError(0), _localErrorRatio(0)
 {
 }
